# AIOLyric

Python package for the Honeywell Lyric Platform.

## Attributions / Contributions

- [@bramkragten](https://github.com/bramkragten) for the original implementation. Referenced his [package](https://github.com/bramkragten/python-lyric) quite a bit whilst writing this one.
- [@ludeeus](https://github.com/ludeeus) for his generator class. Made reading json into objects super simple. :tada:
- [Everyone else](https://github.com/timmo001/aiolyric/graphs/contributors). Thanks for the help!
